# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.application import application_manager_pb2 as prodvana_dot_application_dot_application__manager__pb2


class ApplicationManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigureApplication = channel.unary_unary(
                '/prodvana.application.ApplicationManager/ConfigureApplication',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.ConfigureApplicationReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.ConfigureApplicationResp.FromString,
                )
        self.ValidateConfigureApplication = channel.unary_unary(
                '/prodvana.application.ApplicationManager/ValidateConfigureApplication',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.ConfigureApplicationReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.ValidateConfigureApplicationResp.FromString,
                )
        self.ListApplications = channel.unary_unary(
                '/prodvana.application.ApplicationManager/ListApplications',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.ListApplicationsReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.ListApplicationsResp.FromString,
                )
        self.GetApplicationConfig = channel.unary_unary(
                '/prodvana.application.ApplicationManager/GetApplicationConfig',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationConfigResp.FromString,
                )
        self.ListApplicationConfigVersions = channel.unary_unary(
                '/prodvana.application.ApplicationManager/ListApplicationConfigVersions',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.ListApplicationConfigVersionsReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.ListApplicationConfigVersionsResp.FromString,
                )
        self.GetApplication = channel.unary_unary(
                '/prodvana.application.ApplicationManager/GetApplication',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationResp.FromString,
                )
        self.DeleteApplication = channel.unary_unary(
                '/prodvana.application.ApplicationManager/DeleteApplication',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.DeleteApplicationReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.DeleteApplicationResp.FromString,
                )
        self.GetApplicationMetrics = channel.unary_unary(
                '/prodvana.application.ApplicationManager/GetApplicationMetrics',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetricsReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetricsResp.FromString,
                )
        self.GetApplicationInsights = channel.unary_unary(
                '/prodvana.application.ApplicationManager/GetApplicationInsights',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationInsightsReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationInsightsResp.FromString,
                )
        self.SnoozeApplicationInsight = channel.unary_unary(
                '/prodvana.application.ApplicationManager/SnoozeApplicationInsight',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.SnoozeApplicationInsightReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.SnoozeApplicationInsightResp.FromString,
                )
        self.GetApplicationMetadata = channel.unary_unary(
                '/prodvana.application.ApplicationManager/GetApplicationMetadata',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetadataReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetadataResp.FromString,
                )
        self.SetApplicationMetadata = channel.unary_unary(
                '/prodvana.application.ApplicationManager/SetApplicationMetadata',
                request_serializer=prodvana_dot_application_dot_application__manager__pb2.SetApplicationMetadataReq.SerializeToString,
                response_deserializer=prodvana_dot_application_dot_application__manager__pb2.SetApplicationMetadataResp.FromString,
                )


class ApplicationManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConfigureApplication(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateConfigureApplication(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListApplications(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApplicationConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListApplicationConfigVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApplication(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteApplication(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApplicationMetrics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApplicationInsights(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SnoozeApplicationInsight(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApplicationMetadata(self, request, context):
        """Get application metadata, useful for constructing edit workflows for metadata
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetApplicationMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ApplicationManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigureApplication': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureApplication,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.ConfigureApplicationReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.ConfigureApplicationResp.SerializeToString,
            ),
            'ValidateConfigureApplication': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateConfigureApplication,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.ConfigureApplicationReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.ValidateConfigureApplicationResp.SerializeToString,
            ),
            'ListApplications': grpc.unary_unary_rpc_method_handler(
                    servicer.ListApplications,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.ListApplicationsReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.ListApplicationsResp.SerializeToString,
            ),
            'GetApplicationConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApplicationConfig,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationConfigReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationConfigResp.SerializeToString,
            ),
            'ListApplicationConfigVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListApplicationConfigVersions,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.ListApplicationConfigVersionsReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.ListApplicationConfigVersionsResp.SerializeToString,
            ),
            'GetApplication': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApplication,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationResp.SerializeToString,
            ),
            'DeleteApplication': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteApplication,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.DeleteApplicationReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.DeleteApplicationResp.SerializeToString,
            ),
            'GetApplicationMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApplicationMetrics,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetricsReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetricsResp.SerializeToString,
            ),
            'GetApplicationInsights': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApplicationInsights,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationInsightsReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationInsightsResp.SerializeToString,
            ),
            'SnoozeApplicationInsight': grpc.unary_unary_rpc_method_handler(
                    servicer.SnoozeApplicationInsight,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.SnoozeApplicationInsightReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.SnoozeApplicationInsightResp.SerializeToString,
            ),
            'GetApplicationMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApplicationMetadata,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetadataReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetadataResp.SerializeToString,
            ),
            'SetApplicationMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.SetApplicationMetadata,
                    request_deserializer=prodvana_dot_application_dot_application__manager__pb2.SetApplicationMetadataReq.FromString,
                    response_serializer=prodvana_dot_application_dot_application__manager__pb2.SetApplicationMetadataResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.application.ApplicationManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ApplicationManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConfigureApplication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/ConfigureApplication',
            prodvana_dot_application_dot_application__manager__pb2.ConfigureApplicationReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.ConfigureApplicationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateConfigureApplication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/ValidateConfigureApplication',
            prodvana_dot_application_dot_application__manager__pb2.ConfigureApplicationReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.ValidateConfigureApplicationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListApplications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/ListApplications',
            prodvana_dot_application_dot_application__manager__pb2.ListApplicationsReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.ListApplicationsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetApplicationConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/GetApplicationConfig',
            prodvana_dot_application_dot_application__manager__pb2.GetApplicationConfigReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.GetApplicationConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListApplicationConfigVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/ListApplicationConfigVersions',
            prodvana_dot_application_dot_application__manager__pb2.ListApplicationConfigVersionsReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.ListApplicationConfigVersionsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetApplication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/GetApplication',
            prodvana_dot_application_dot_application__manager__pb2.GetApplicationReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.GetApplicationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteApplication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/DeleteApplication',
            prodvana_dot_application_dot_application__manager__pb2.DeleteApplicationReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.DeleteApplicationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetApplicationMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/GetApplicationMetrics',
            prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetricsReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetricsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetApplicationInsights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/GetApplicationInsights',
            prodvana_dot_application_dot_application__manager__pb2.GetApplicationInsightsReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.GetApplicationInsightsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SnoozeApplicationInsight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/SnoozeApplicationInsight',
            prodvana_dot_application_dot_application__manager__pb2.SnoozeApplicationInsightReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.SnoozeApplicationInsightResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetApplicationMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/GetApplicationMetadata',
            prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetadataReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.GetApplicationMetadataResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetApplicationMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.application.ApplicationManager/SetApplicationMetadata',
            prodvana_dot_application_dot_application__manager__pb2.SetApplicationMetadataReq.SerializeToString,
            prodvana_dot_application_dot_application__manager__pb2.SetApplicationMetadataResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/organization/organization_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from prodvana.proto.prodvana.config_writeback import writeback_pb2 as prodvana_dot_config__writeback_dot_writeback__pb2
from prodvana.proto.prodvana.insights import insights_pb2 as prodvana_dot_insights_dot_insights__pb2
from prodvana.proto.prodvana.metrics import metrics_pb2 as prodvana_dot_metrics_dot_metrics__pb2
from prodvana.proto.prodvana.organization import user_metadata_pb2 as prodvana_dot_organization_dot_user__metadata__pb2
from prodvana.proto.prodvana.users import users_pb2 as prodvana_dot_users_dot_users__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0prodvana/organization/organization_manager.proto\x12\x15prodvana.organization\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a)prodvana/config_writeback/writeback.proto\x1a prodvana/insights/insights.proto\x1a\x1eprodvana/metrics/metrics.proto\x1a)prodvana/organization/user_metadata.proto\x1a\x1aprodvana/users/users.proto\x1a\x17validate/validate.proto\"\xe8\x01\n\x10OrganizationInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12H\n\x10writeback_config\x18\x03 \x01(\x0b\x32..prodvana.config_writeback.ConfigWritebackPath\x12\x0c\n\x04slug\x18\x04 \x01(\t\x12\x46\n\ruser_metadata\x18\x05 \x01(\x0b\x32/.prodvana.organization.OrganizationUserMetadata\x12\x12\n\nui_address\x18\x06 \x01(\t\"\x14\n\x12GetOrganizationReq\"T\n\x13GetOrganizationResp\x12=\n\x0corganization\x18\x01 \x01(\x0b\x32\'.prodvana.organization.OrganizationInfo\"\x83\x01\n\x19GetOrganizationMetricsReq\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"]\n\x1aGetOrganizationMetricsResp\x12?\n\x12\x64\x65ployment_metrics\x18\x01 \x01(\x0b\x32#.prodvana.metrics.DeploymentMetrics\"\x1c\n\x1aGetOrganizationInsightsReq\"K\n\x1bGetOrganizationInsightsResp\x12,\n\x08insights\x18\x01 \x03(\x0b\x32\x1a.prodvana.insights.Insight\"\x8a\x01\n\x1cSnoozeOrganizationInsightReq\x12\x31\n\x05\x63lass\x18\x01 \x01(\x0e\x32\x18.prodvana.insights.ClassB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x37\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\"\x1f\n\x1dSnoozeOrganizationInsightResp\"\x1c\n\x1aGetOrganizationMetadataReq\"`\n\x1bGetOrganizationMetadataResp\x12\x41\n\x08metadata\x18\x01 \x01(\x0b\x32/.prodvana.organization.OrganizationUserMetadata\"i\n\x1aSetOrganizationMetadataReq\x12K\n\x08metadata\x18\x01 \x01(\x0b\x32/.prodvana.organization.OrganizationUserMetadataB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x1d\n\x1bSetOrganizationMetadataResp\"&\n\nGetUserReq\x12\x18\n\x07user_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"1\n\x0bGetUserResp\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.prodvana.users.User\"6\n$GetOrganizationSubscriptionStatusReq\x12\x0e\n\x06org_id\x18\x01 \x01(\t\"\x7f\n%GetOrganizationSubscriptionStatusResp\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12\r\n\x05trial\x18\x02 \x01(\x08\x12\x37\n\x13trial_end_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"5\n\x14OrganizationSettings\x12\x1d\n\x15\x65nable_ai_integration\x18\x01 \x01(\x08\"V\n\x19OrganizationSettingsDelta\x12\x39\n\x15\x65nable_ai_integration\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x1c\n\x1aGetOrganizationSettingsReq\"\\\n\x1bGetOrganizationSettingsResp\x12=\n\x08settings\x18\x01 \x01(\x0b\x32+.prodvana.organization.OrganizationSettings\"j\n\x1aSetOrganizationSettingsReq\x12L\n\x08settings\x18\x01 \x01(\x0b\x32\x30.prodvana.organization.OrganizationSettingsDeltaB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x1d\n\x1bSetOrganizationSettingsResp2\xff\x0c\n\x13OrganizationManager\x12\x82\x01\n\x0fGetOrganization\x12).prodvana.organization.GetOrganizationReq\x1a*.prodvana.organization.GetOrganizationResp\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/organization\x12\x9f\x01\n\x16GetOrganizationMetrics\x12\x30.prodvana.organization.GetOrganizationMetricsReq\x1a\x31.prodvana.organization.GetOrganizationMetricsResp\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/organization/metrics\x12\xa3\x01\n\x17GetOrganizationInsights\x12\x31.prodvana.organization.GetOrganizationInsightsReq\x1a\x32.prodvana.organization.GetOrganizationInsightsResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/organization/insights\x12\xb0\x01\n\x19SnoozeOrganizationInsight\x12\x33.prodvana.organization.SnoozeOrganizationInsightReq\x1a\x34.prodvana.organization.SnoozeOrganizationInsightResp\"(\x82\xd3\xe4\x93\x02\"\x1a /v1/organization/insights/snooze\x12\xa3\x01\n\x17GetOrganizationMetadata\x12\x31.prodvana.organization.GetOrganizationMetadataReq\x1a\x32.prodvana.organization.GetOrganizationMetadataResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/organization/metadata\x12\xa6\x01\n\x17SetOrganizationMetadata\x12\x31.prodvana.organization.SetOrganizationMetadataReq\x1a\x32.prodvana.organization.SetOrganizationMetadataResp\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/organization/metadata:\x01*\x12{\n\x07GetUser\x12!.prodvana.organization.GetUserReq\x1a\".prodvana.organization.GetUserResp\")\x82\xd3\xe4\x93\x02#\x12!/v1/organization/user/{user_id=*}\x12\xcc\x01\n!GetOrganizationSubscriptionStatus\x12;.prodvana.organization.GetOrganizationSubscriptionStatusReq\x1a<.prodvana.organization.GetOrganizationSubscriptionStatusResp\",\x82\xd3\xe4\x93\x02&\x12$/v1/organization/subscription/status\x12\xa3\x01\n\x17GetOrganizationSettings\x12\x31.prodvana.organization.GetOrganizationSettingsReq\x1a\x32.prodvana.organization.GetOrganizationSettingsResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/organization/settings\x12\xa6\x01\n\x17SetOrganizationSettings\x12\x31.prodvana.organization.SetOrganizationSettingsReq\x1a\x32.prodvana.organization.SetOrganizationSettingsResp\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/organization/settings:\x01*BQZOgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/organizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.organization.organization_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZOgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/organization'
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['class']._options = None
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['class']._serialized_options = b'\372B\005\202\001\002\020\001'
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['duration']._options = None
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['duration']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _SETORGANIZATIONMETADATAREQ.fields_by_name['metadata']._options = None
  _SETORGANIZATIONMETADATAREQ.fields_by_name['metadata']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETUSERREQ.fields_by_name['user_id']._options = None
  _GETUSERREQ.fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _SETORGANIZATIONSETTINGSREQ.fields_by_name['settings']._options = None
  _SETORGANIZATIONSETTINGSREQ.fields_by_name['settings']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganization']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganization']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/organization'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetrics']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetrics']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/organization/metrics'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationInsights']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationInsights']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/organization/insights'
  _ORGANIZATIONMANAGER.methods_by_name['SnoozeOrganizationInsight']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['SnoozeOrganizationInsight']._serialized_options = b'\202\323\344\223\002\"\032 /v1/organization/insights/snooze'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetadata']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetadata']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/organization/metadata'
  _ORGANIZATIONMANAGER.methods_by_name['SetOrganizationMetadata']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['SetOrganizationMetadata']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/organization/metadata:\001*'
  _ORGANIZATIONMANAGER.methods_by_name['GetUser']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetUser']._serialized_options = b'\202\323\344\223\002#\022!/v1/organization/user/{user_id=*}'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationSubscriptionStatus']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationSubscriptionStatus']._serialized_options = b'\202\323\344\223\002&\022$/v1/organization/subscription/status'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationSettings']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationSettings']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/organization/settings'
  _ORGANIZATIONMANAGER.methods_by_name['SetOrganizationSettings']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['SetOrganizationSettings']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/organization/settings:\001*'
  _globals['_ORGANIZATIONINFO']._serialized_start=408
  _globals['_ORGANIZATIONINFO']._serialized_end=640
  _globals['_GETORGANIZATIONREQ']._serialized_start=642
  _globals['_GETORGANIZATIONREQ']._serialized_end=662
  _globals['_GETORGANIZATIONRESP']._serialized_start=664
  _globals['_GETORGANIZATIONRESP']._serialized_end=748
  _globals['_GETORGANIZATIONMETRICSREQ']._serialized_start=751
  _globals['_GETORGANIZATIONMETRICSREQ']._serialized_end=882
  _globals['_GETORGANIZATIONMETRICSRESP']._serialized_start=884
  _globals['_GETORGANIZATIONMETRICSRESP']._serialized_end=977
  _globals['_GETORGANIZATIONINSIGHTSREQ']._serialized_start=979
  _globals['_GETORGANIZATIONINSIGHTSREQ']._serialized_end=1007
  _globals['_GETORGANIZATIONINSIGHTSRESP']._serialized_start=1009
  _globals['_GETORGANIZATIONINSIGHTSRESP']._serialized_end=1084
  _globals['_SNOOZEORGANIZATIONINSIGHTREQ']._serialized_start=1087
  _globals['_SNOOZEORGANIZATIONINSIGHTREQ']._serialized_end=1225
  _globals['_SNOOZEORGANIZATIONINSIGHTRESP']._serialized_start=1227
  _globals['_SNOOZEORGANIZATIONINSIGHTRESP']._serialized_end=1258
  _globals['_GETORGANIZATIONMETADATAREQ']._serialized_start=1260
  _globals['_GETORGANIZATIONMETADATAREQ']._serialized_end=1288
  _globals['_GETORGANIZATIONMETADATARESP']._serialized_start=1290
  _globals['_GETORGANIZATIONMETADATARESP']._serialized_end=1386
  _globals['_SETORGANIZATIONMETADATAREQ']._serialized_start=1388
  _globals['_SETORGANIZATIONMETADATAREQ']._serialized_end=1493
  _globals['_SETORGANIZATIONMETADATARESP']._serialized_start=1495
  _globals['_SETORGANIZATIONMETADATARESP']._serialized_end=1524
  _globals['_GETUSERREQ']._serialized_start=1526
  _globals['_GETUSERREQ']._serialized_end=1564
  _globals['_GETUSERRESP']._serialized_start=1566
  _globals['_GETUSERRESP']._serialized_end=1615
  _globals['_GETORGANIZATIONSUBSCRIPTIONSTATUSREQ']._serialized_start=1617
  _globals['_GETORGANIZATIONSUBSCRIPTIONSTATUSREQ']._serialized_end=1671
  _globals['_GETORGANIZATIONSUBSCRIPTIONSTATUSRESP']._serialized_start=1673
  _globals['_GETORGANIZATIONSUBSCRIPTIONSTATUSRESP']._serialized_end=1800
  _globals['_ORGANIZATIONSETTINGS']._serialized_start=1802
  _globals['_ORGANIZATIONSETTINGS']._serialized_end=1855
  _globals['_ORGANIZATIONSETTINGSDELTA']._serialized_start=1857
  _globals['_ORGANIZATIONSETTINGSDELTA']._serialized_end=1943
  _globals['_GETORGANIZATIONSETTINGSREQ']._serialized_start=1945
  _globals['_GETORGANIZATIONSETTINGSREQ']._serialized_end=1973
  _globals['_GETORGANIZATIONSETTINGSRESP']._serialized_start=1975
  _globals['_GETORGANIZATIONSETTINGSRESP']._serialized_end=2067
  _globals['_SETORGANIZATIONSETTINGSREQ']._serialized_start=2069
  _globals['_SETORGANIZATIONSETTINGSREQ']._serialized_end=2175
  _globals['_SETORGANIZATIONSETTINGSRESP']._serialized_start=2177
  _globals['_SETORGANIZATIONSETTINGSRESP']._serialized_end=2206
  _globals['_ORGANIZATIONMANAGER']._serialized_start=2209
  _globals['_ORGANIZATIONMANAGER']._serialized_end=3872
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/dangerous_action.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-prodvana/common_config/dangerous_action.proto\x12\x16prodvana.common_config\"2\n\x0f\x44\x61ngerousAction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x65xplanation\x18\x02 \x01(\tBRZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.dangerous_action_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _globals['_DANGEROUSACTION']._serialized_start=73
  _globals['_DANGEROUSACTION']._serialized_end=123
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CommitDenylistProtectionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class CommitDefinition(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class Range(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            START_COMMIT_FIELD_NUMBER: builtins.int
            END_COMMIT_FIELD_NUMBER: builtins.int
            start_commit: builtins.str
            """older commit, exclusive"""
            end_commit: builtins.str
            """newer commit, inclusive"""
            def __init__(
                self,
                *,
                start_commit: builtins.str = ...,
                end_commit: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["end_commit", b"end_commit", "start_commit", b"start_commit"]) -> None: ...

        COMMIT_FIELD_NUMBER: builtins.int
        RANGE_FIELD_NUMBER: builtins.int
        commit: builtins.str
        @property
        def range(self) -> global___CommitDenylistProtectionConfig.CommitDefinition.Range: ...
        def __init__(
            self,
            *,
            commit: builtins.str = ...,
            range: global___CommitDenylistProtectionConfig.CommitDefinition.Range | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["commit", b"commit", "commit_oneof", b"commit_oneof", "range", b"range"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["commit", b"commit", "commit_oneof", b"commit_oneof", "range", b"range"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["commit_oneof", b"commit_oneof"]) -> typing_extensions.Literal["commit", "range"] | None: ...

    REPOSITORY_FIELD_NUMBER: builtins.int
    COMMITS_FIELD_NUMBER: builtins.int
    repository: builtins.str
    @property
    def commits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommitDenylistProtectionConfig.CommitDefinition]: ...
    def __init__(
        self,
        *,
        repository: builtins.str = ...,
        commits: collections.abc.Iterable[global___CommitDenylistProtectionConfig.CommitDefinition] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commits", b"commits", "repository", b"repository"]) -> None: ...

global___CommitDenylistProtectionConfig = CommitDenylistProtectionConfig

class TimeWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_FIELD_NUMBER: builtins.int
    HOURS_FIELD_NUMBER: builtins.int
    TZ_FIELD_NUMBER: builtins.int
    days: builtins.str
    """Supports aliases (weekdays and weekends), as well as ranges and comma separated lists of days
    short (mon-thu) or full (monday-thursday)
    """
    hours: builtins.str
    """Supports ranges (i.e. 10-20) and comma separated lists (i.e. 5,6,7,8) or a combination of the two"""
    tz: builtins.str
    """defaults to UTC
    supported values are: Africa/Abidjan, Africa/Accra, Africa/Addis_Ababa, Africa/Algiers, Africa/Asmara, Africa/Asmera, Africa/Bamako, Africa/Bangui, Africa/Banjul, Africa/Bissau, Africa/Blantyre, Africa/Brazzaville, Africa/Bujumbura, Africa/Cairo, Africa/Casablanca, Africa/Ceuta, Africa/Conakry, Africa/Dakar, Africa/Dar_es_Salaam, Africa/Djibouti, Africa/Douala, Africa/El_Aaiun, Africa/Freetown, Africa/Gaborone, Africa/Harare, Africa/Johannesburg, Africa/Juba, Africa/Kampala, Africa/Khartoum, Africa/Kigali, Africa/Kinshasa, Africa/Lagos, Africa/Libreville, Africa/Lome, Africa/Luanda, Africa/Lubumbashi, Africa/Lusaka, Africa/Malabo, Africa/Maputo, Africa/Maseru, Africa/Mbabane, Africa/Mogadishu, Africa/Monrovia, Africa/Nairobi, Africa/Ndjamena, Africa/Niamey, Africa/Nouakchott, Africa/Ouagadougou, Africa/Porto-Novo, Africa/Sao_Tome, Africa/Timbuktu, Africa/Tripoli, Africa/Tunis, Africa/Windhoek, America/Adak, America/Anchorage, America/Anguilla, America/Antigua, America/Araguaina, America/Argentina/Buenos_Aires, America/Argentina/Catamarca, America/Argentina/ComodRivadavia, America/Argentina/Cordoba, America/Argentina/Jujuy, America/Argentina/La_Rioja, America/Argentina/Mendoza, America/Argentina/Rio_Gallegos, America/Argentina/Salta, America/Argentina/San_Juan, America/Argentina/San_Luis, America/Argentina/Tucuman, America/Argentina/Ushuaia, America/Aruba, America/Asuncion, America/Atikokan, America/Atka, America/Bahia, America/Bahia_Banderas, America/Barbados, America/Belem, America/Belize, America/Blanc-Sablon, America/Boa_Vista, America/Bogota, America/Boise, America/Buenos_Aires, America/Cambridge_Bay, America/Campo_Grande, America/Cancun, America/Caracas, America/Catamarca, America/Cayenne, America/Cayman, America/Chicago, America/Chihuahua, America/Coral_Harbour, America/Cordoba, America/Costa_Rica, America/Creston, America/Cuiaba, America/Curacao, America/Danmarkshavn, America/Dawson, America/Dawson_Creek, America/Denver, America/Detroit, America/Dominica, America/Edmonton, America/Eirunepe, America/El_Salvador, America/Ensenada, America/Fort_Nelson, America/Fort_Wayne, America/Fortaleza, America/Glace_Bay, America/Godthab, America/Goose_Bay, America/Grand_Turk, America/Grenada, America/Guadeloupe, America/Guatemala, America/Guayaquil, America/Guyana, America/Halifax, America/Havana, America/Hermosillo, America/Indiana/Indianapolis, America/Indiana/Knox, America/Indiana/Marengo, America/Indiana/Petersburg, America/Indiana/Tell_City, America/Indiana/Vevay, America/Indiana/Vincennes, America/Indiana/Winamac, America/Indianapolis, America/Inuvik, America/Iqaluit, America/Jamaica, America/Jujuy, America/Juneau, America/Kentucky/Louisville, America/Kentucky/Monticello, America/Knox_IN, America/Kralendijk, America/La_Paz, America/Lima, America/Los_Angeles, America/Louisville, America/Lower_Princes, America/Maceio, America/Managua, America/Manaus, America/Marigot, America/Martinique, America/Matamoros, America/Mazatlan, America/Mendoza, America/Menominee, America/Merida, America/Metlakatla, America/Mexico_City, America/Miquelon, America/Moncton, America/Monterrey, America/Montevideo, America/Montreal, America/Montserrat, America/Nassau, America/New_York, America/Nipigon, America/Nome, America/Noronha, America/North_Dakota/Beulah, America/North_Dakota/Center, America/North_Dakota/New_Salem, America/Nuuk, America/Ojinaga, America/Panama, America/Pangnirtung, America/Paramaribo, America/Phoenix, America/Port-au-Prince, America/Port_of_Spain, America/Porto_Acre, America/Porto_Velho, America/Puerto_Rico, America/Punta_Arenas, America/Rainy_River, America/Rankin_Inlet, America/Recife, America/Regina, America/Resolute, America/Rio_Branco, America/Rosario, America/Santa_Isabel, America/Santarem, America/Santiago, America/Santo_Domingo, America/Sao_Paulo, America/Scoresbysund, America/Shiprock, America/Sitka, America/St_Barthelemy, America/St_Johns, America/St_Kitts, America/St_Lucia, America/St_Thomas, America/St_Vincent, America/Swift_Current, America/Tegucigalpa, America/Thule, America/Thunder_Bay, America/Tijuana, America/Toronto, America/Tortola, America/Vancouver, America/Virgin, America/Whitehorse, America/Winnipeg, America/Yakutat, America/Yellowknife, Antarctica/Casey, Antarctica/Davis, Antarctica/DumontDUrville, Antarctica/Macquarie, Antarctica/Mawson, Antarctica/McMurdo, Antarctica/Palmer, Antarctica/Rothera, Antarctica/South_Pole, Antarctica/Syowa, Antarctica/Troll, Antarctica/Vostok, Arctic/Longyearbyen, Asia/Aden, Asia/Almaty, Asia/Amman, Asia/Anadyr, Asia/Aqtau, Asia/Aqtobe, Asia/Ashgabat, Asia/Ashkhabad, Asia/Atyrau, Asia/Baghdad, Asia/Bahrain, Asia/Baku, Asia/Bangkok, Asia/Barnaul, Asia/Beirut, Asia/Bishkek, Asia/Brunei, Asia/Calcutta, Asia/Chita, Asia/Choibalsan, Asia/Chongqing, Asia/Chungking, Asia/Colombo, Asia/Dacca, Asia/Damascus, Asia/Dhaka, Asia/Dili, Asia/Dubai, Asia/Dushanbe, Asia/Famagusta, Asia/Gaza, Asia/Harbin, Asia/Hebron, Asia/Ho_Chi_Minh, Asia/Hong_Kong, Asia/Hovd, Asia/Irkutsk, Asia/Istanbul, Asia/Jakarta, Asia/Jayapura, Asia/Jerusalem, Asia/Kabul, Asia/Kamchatka, Asia/Karachi, Asia/Kashgar, Asia/Kathmandu, Asia/Katmandu, Asia/Khandyga, Asia/Kolkata, Asia/Krasnoyarsk, Asia/Kuala_Lumpur, Asia/Kuching, Asia/Kuwait, Asia/Macao, Asia/Macau, Asia/Magadan, Asia/Makassar, Asia/Manila, Asia/Muscat, Asia/Nicosia, Asia/Novokuznetsk, Asia/Novosibirsk, Asia/Omsk, Asia/Oral, Asia/Phnom_Penh, Asia/Pontianak, Asia/Pyongyang, Asia/Qatar, Asia/Qostanay, Asia/Qyzylorda, Asia/Rangoon, Asia/Riyadh, Asia/Saigon, Asia/Sakhalin, Asia/Samarkand, Asia/Seoul, Asia/Shanghai, Asia/Singapore, Asia/Srednekolymsk, Asia/Taipei, Asia/Tashkent, Asia/Tbilisi, Asia/Tehran, Asia/Tel_Aviv, Asia/Thimbu, Asia/Thimphu, Asia/Tokyo, Asia/Tomsk, Asia/Ujung_Pandang, Asia/Ulaanbaatar, Asia/Ulan_Bator, Asia/Urumqi, Asia/Ust-Nera, Asia/Vientiane, Asia/Vladivostok, Asia/Yakutsk, Asia/Yangon, Asia/Yekaterinburg, Asia/Yerevan, Atlantic/Azores, Atlantic/Bermuda, Atlantic/Canary, Atlantic/Cape_Verde, Atlantic/Faeroe, Atlantic/Faroe, Atlantic/Jan_Mayen, Atlantic/Madeira, Atlantic/Reykjavik, Atlantic/South_Georgia, Atlantic/St_Helena, Atlantic/Stanley, Australia/ACT, Australia/Adelaide, Australia/Brisbane, Australia/Broken_Hill, Australia/Canberra, Australia/Currie, Australia/Darwin, Australia/Eucla, Australia/Hobart, Australia/LHI, Australia/Lindeman, Australia/Lord_Howe, Australia/Melbourne, Australia/NSW, Australia/North, Australia/Perth, Australia/Queensland, Australia/South, Australia/Sydney, Australia/Tasmania, Australia/Victoria, Australia/West, Australia/Yancowinna, Brazil/Acre, Brazil/DeNoronha, Brazil/East, Brazil/West, CET, CST6CDT, Canada/Atlantic, Canada/Central, Canada/Eastern, Canada/Mountain, Canada/Newfoundland, Canada/Pacific, Canada/Saskatchewan, Canada/Yukon, Chile/Continental, Chile/EasterIsland, Cuba, EET, EST, EST5EDT, Egypt, Eire, Etc/GMT, Etc/GMT+0, Etc/GMT+1, Etc/GMT+10, Etc/GMT+11, Etc/GMT+12, Etc/GMT+2, Etc/GMT+3, Etc/GMT+4, Etc/GMT+5, Etc/GMT+6, Etc/GMT+7, Etc/GMT+8, Etc/GMT+9, Etc/GMT-0, Etc/GMT-1, Etc/GMT-10, Etc/GMT-11, Etc/GMT-12, Etc/GMT-13, Etc/GMT-14, Etc/GMT-2, Etc/GMT-3, Etc/GMT-4, Etc/GMT-5, Etc/GMT-6, Etc/GMT-7, Etc/GMT-8, Etc/GMT-9, Etc/GMT0, Etc/Greenwich, Etc/UCT, Etc/UTC, Etc/Universal, Etc/Zulu, Europe/Amsterdam, Europe/Andorra, Europe/Astrakhan, Europe/Athens, Europe/Belfast, Europe/Belgrade, Europe/Berlin, Europe/Bratislava, Europe/Brussels, Europe/Bucharest, Europe/Budapest, Europe/Busingen, Europe/Chisinau, Europe/Copenhagen, Europe/Dublin, Europe/Gibraltar, Europe/Guernsey, Europe/Helsinki, Europe/Isle_of_Man, Europe/Istanbul, Europe/Jersey, Europe/Kaliningrad, Europe/Kiev, Europe/Kirov, Europe/Kyiv, Europe/Lisbon, Europe/Ljubljana, Europe/London, Europe/Luxembourg, Europe/Madrid, Europe/Malta, Europe/Mariehamn, Europe/Minsk, Europe/Monaco, Europe/Moscow, Europe/Nicosia, Europe/Oslo, Europe/Paris, Europe/Podgorica, Europe/Prague, Europe/Riga, Europe/Rome, Europe/Samara, Europe/San_Marino, Europe/Sarajevo, Europe/Saratov, Europe/Simferopol, Europe/Skopje, Europe/Sofia, Europe/Stockholm, Europe/Tallinn, Europe/Tirane, Europe/Tiraspol, Europe/Ulyanovsk, Europe/Uzhgorod, Europe/Vaduz, Europe/Vatican, Europe/Vienna, Europe/Vilnius, Europe/Volgograd, Europe/Warsaw, Europe/Zagreb, Europe/Zaporozhye, Europe/Zurich, GB, GB-Eire, GMT, GMT+0, GMT-0, GMT0, Greenwich, HST, Hongkong, Iceland, Indian/Antananarivo, Indian/Chagos, Indian/Christmas, Indian/Cocos, Indian/Comoro, Indian/Kerguelen, Indian/Mahe, Indian/Maldives, Indian/Mauritius, Indian/Mayotte, Indian/Reunion, Iran, Israel, Jamaica, Japan, Kwajalein, Libya, MET, MST, MST7MDT, Mexico/BajaNorte, Mexico/BajaSur, Mexico/General, NZ, NZ-CHAT, Navajo, PRC, PST8PDT, Pacific/Apia, Pacific/Auckland, Pacific/Bougainville, Pacific/Chatham, Pacific/Chuuk, Pacific/Easter, Pacific/Efate, Pacific/Enderbury, Pacific/Fakaofo, Pacific/Fiji, Pacific/Funafuti, Pacific/Galapagos, Pacific/Gambier, Pacific/Guadalcanal, Pacific/Guam, Pacific/Honolulu, Pacific/Johnston, Pacific/Kanton, Pacific/Kiritimati, Pacific/Kosrae, Pacific/Kwajalein, Pacific/Majuro, Pacific/Marquesas, Pacific/Midway, Pacific/Nauru, Pacific/Niue, Pacific/Norfolk, Pacific/Noumea, Pacific/Pago_Pago, Pacific/Palau, Pacific/Pitcairn, Pacific/Pohnpei, Pacific/Ponape, Pacific/Port_Moresby, Pacific/Rarotonga, Pacific/Saipan, Pacific/Samoa, Pacific/Tahiti, Pacific/Tarawa, Pacific/Tongatapu, Pacific/Truk, Pacific/Wake, Pacific/Wallis, Pacific/Yap, Poland, Portugal, ROC, ROK, Singapore, Turkey, UCT, US/Alaska, US/Aleutian, US/Arizona, US/Central, US/East-Indiana, US/Eastern, US/Hawaii, US/Indiana-Starke, US/Michigan, US/Mountain, US/Pacific, US/Samoa, UTC, Universal, W-SU, WET, Zulu
    case insensitive
    """
    def __init__(
        self,
        *,
        days: builtins.str = ...,
        hours: builtins.str = ...,
        tz: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["days", b"days", "hours", b"hours", "tz", b"tz"]) -> None: ...

global___TimeWindow = TimeWindow

class AllowedTimesProtectionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WINDOWS_FIELD_NUMBER: builtins.int
    @property
    def windows(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimeWindow]: ...
    def __init__(
        self,
        *,
        windows: collections.abc.Iterable[global___TimeWindow] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["windows", b"windows"]) -> None: ...

global___AllowedTimesProtectionConfig = AllowedTimesProtectionConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/desired_state/debug/debug.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.desired_state.model import desired_state_pb2 as prodvana_dot_desired__state_dot_model_dot_desired__state__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(prodvana/desired_state/debug/debug.proto\x12\x1cprodvana.desired_state.debug\x1a\x30prodvana/desired_state/model/desired_state.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd3\x07\n\x0f\x45ntityDumpState\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x41\n\x1dlast_manager_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x0b\x61nnotations\x18\x03 \x01(\x0b\x32).prodvana.desired_state.model.Annotations\x12\x34\n\x06status\x18\x04 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\x41\n\rsimple_status\x18\x0b \x01(\x0e\x32*.prodvana.desired_state.model.SimpleStatus\x12;\n\x07\x63ontrol\x18\x05 \x01(\x0b\x32*.prodvana.desired_state.model.ControlState\x12G\n\x08io_state\x18\x06 \x01(\x0b\x32\x35.prodvana.desired_state.debug.EntityDumpState.IOState\x12\x34\n\x04logs\x18\x07 \x03(\x0b\x32&.prodvana.desired_state.model.DebugLog\x12+\n\rdesired_state\x18\x08 \x01(\x0b\x32\x14.google.protobuf.Any\x12+\n\rfetched_state\x18\t \x01(\x0b\x32\x14.google.protobuf.Any\x12*\n\x0ctarget_state\x18\x0c \x01(\x0b\x32\x14.google.protobuf.Any\x12N\n\x0c\x63hild_states\x18\n \x03(\x0b\x32\x38.prodvana.desired_state.debug.EntityDumpState.ChildState\x1a\x81\x01\n\x07IOState\x12:\n\x16last_fetched_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_applied_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1ax\n\nChildState\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x34\n\x06status\x18\x02 \x01(\x0e\x32$.prodvana.desired_state.model.Status\"L\n\tDumpState\x12?\n\x08\x65ntities\x18\x01 \x03(\x0b\x32-.prodvana.desired_state.debug.EntityDumpStateBXZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/debugb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.desired_state.debug.debug_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/debug'
  _globals['_ENTITYDUMPSTATE']._serialized_start=185
  _globals['_ENTITYDUMPSTATE']._serialized_end=1164
  _globals['_ENTITYDUMPSTATE_IOSTATE']._serialized_start=913
  _globals['_ENTITYDUMPSTATE_IOSTATE']._serialized_end=1042
  _globals['_ENTITYDUMPSTATE_CHILDSTATE']._serialized_start=1044
  _globals['_ENTITYDUMPSTATE_CHILDSTATE']._serialized_end=1164
  _globals['_DUMPSTATE']._serialized_start=1166
  _globals['_DUMPSTATE']._serialized_end=1242
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.deployment import manager_pb2 as prodvana_dot_deployment_dot_manager__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprodvana/release/manager.proto\x12\x10prodvana.release\x1a\x1cgoogle/api/annotations.proto\x1a!prodvana/deployment/manager.proto2\xe5\x08\n\x0eReleaseManager\x12}\n\rRecordRelease\x12(.prodvana.deployment.RecordDeploymentReq\x1a).prodvana.deployment.RecordDeploymentResp\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/releases:\x01*\x12\xa8\x01\n\x13UpdateReleaseStatus\x12..prodvana.deployment.UpdateDeploymentStatusReq\x1a/.prodvana.deployment.UpdateDeploymentStatusResp\"0\x82\xd3\xe4\x93\x02*\"%/v1/releases/{deployment_id=*}/status:\x01*\x12w\n\x0cListReleases\x12\'.prodvana.deployment.ListDeploymentsReq\x1a(.prodvana.deployment.ListDeploymentsResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/releases\x12k\n\x12ListReleasesStream\x12\'.prodvana.deployment.ListDeploymentsReq\x1a(.prodvana.deployment.ListDeploymentsResp\"\x00\x30\x01\x12\x88\x01\n\x0e\x43ompareRelease\x12).prodvana.deployment.CompareDeploymentReq\x1a*.prodvana.deployment.CompareDeploymentResp\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/releases/compare:\x01*\x12\x88\x01\n\x0ePreviewRelease\x12).prodvana.deployment.PreviewDeploymentReq\x1a*.prodvana.deployment.PreviewDeploymentResp\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/releases/preview:\x01*\x12\x8d\x01\n\x11GetLatestReleases\x12,.prodvana.deployment.GetLatestDeploymentsReq\x1a-.prodvana.deployment.GetLatestDeploymentsResp\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/releases/latest\x12\x9c\x01\n\x14\x43heckCommitInRelease\x12/.prodvana.deployment.CheckCommitInDeploymentReq\x1a\x30.prodvana.deployment.CheckCommitInDeploymentResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/releases/check_commitBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/releaseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.release.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release'
  _RELEASEMANAGER.methods_by_name['RecordRelease']._options = None
  _RELEASEMANAGER.methods_by_name['RecordRelease']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/releases:\001*'
  _RELEASEMANAGER.methods_by_name['UpdateReleaseStatus']._options = None
  _RELEASEMANAGER.methods_by_name['UpdateReleaseStatus']._serialized_options = b'\202\323\344\223\002*\"%/v1/releases/{deployment_id=*}/status:\001*'
  _RELEASEMANAGER.methods_by_name['ListReleases']._options = None
  _RELEASEMANAGER.methods_by_name['ListReleases']._serialized_options = b'\202\323\344\223\002\016\022\014/v1/releases'
  _RELEASEMANAGER.methods_by_name['CompareRelease']._options = None
  _RELEASEMANAGER.methods_by_name['CompareRelease']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/releases/compare:\001*'
  _RELEASEMANAGER.methods_by_name['PreviewRelease']._options = None
  _RELEASEMANAGER.methods_by_name['PreviewRelease']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/releases/preview:\001*'
  _RELEASEMANAGER.methods_by_name['GetLatestReleases']._options = None
  _RELEASEMANAGER.methods_by_name['GetLatestReleases']._serialized_options = b'\202\323\344\223\002\025\022\023/v1/releases/latest'
  _RELEASEMANAGER.methods_by_name['CheckCommitInRelease']._options = None
  _RELEASEMANAGER.methods_by_name['CheckCommitInRelease']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/releases/check_commit'
  _globals['_RELEASEMANAGER']._serialized_start=118
  _globals['_RELEASEMANAGER']._serialized_end=1243
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/pipelines/pipelines.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2
from prodvana.proto.prodvana.common_config import retry_pb2 as prodvana_dot_common__config_dot_retry__pb2
from prodvana.proto.prodvana.common_config import notification_pb2 as prodvana_dot_common__config_dot_notification__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"prodvana/pipelines/pipelines.proto\x12\x12prodvana.pipelines\x1a\x1egoogle/protobuf/duration.proto\x1a\x17validate/validate.proto\x1a$prodvana/common_config/program.proto\x1a\"prodvana/common_config/retry.proto\x1a)prodvana/common_config/notification.proto\"\xa3\x01\n\x08PushTask\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x1a\n\x12release_channel_id\x18\x03 \x01(\t\x12\x17\n\x0frelease_channel\x18\x04 \x01(\t\x12\x10\n\x08rollback\x18\x05 \x01(\x08\x12\x16\n\x0e\x61pplication_id\x18\x06 \x01(\t\x12\x13\n\x0b\x61pplication\x18\x07 \x01(\t\"C\n\x08WaitTask\x12\x37\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\"\x80\x01\n\x0cParallelTask\x12:\n\x06tracks\x18\x01 \x03(\x0b\x32*.prodvana.pipelines.ParallelTask.TaskTrack\x1a\x34\n\tTaskTrack\x12\'\n\x05tasks\x18\x01 \x03(\x0b\x32\x18.prodvana.pipelines.Task\"\x14\n\x12ManualApprovalTask\"\xa9\x02\n\nCustomTask\x12\x1c\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12@\n\x07program\x18\x01 \x01(\x0b\x32%.prodvana.common_config.ProgramConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x39\n\x0cretry_config\x18\x02 \x01(\x0b\x32#.prodvana.common_config.RetryConfig\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x04 \x01(\t\x12\x17\n\x0frelease_channel\x18\x05 \x01(\t\x12\x1a\n\x12release_channel_id\x18\x06 \x01(\t\x12\x1e\n\x16\x66inal_compiled_program\x18\x08 \x01(\x08\"\x86\x03\n\x04Task\x12\x33\n\x08metadata\x18\x01 \x01(\x0b\x32!.prodvana.pipelines.Task.Metadata\x12\x31\n\tpush_task\x18\x02 \x01(\x0b\x32\x1c.prodvana.pipelines.PushTaskH\x00\x12\x31\n\twait_task\x18\x03 \x01(\x0b\x32\x1c.prodvana.pipelines.WaitTaskH\x00\x12\x39\n\rparallel_task\x18\x04 \x01(\x0b\x32 .prodvana.pipelines.ParallelTaskH\x00\x12\x46\n\x14manual_approval_task\x18\x05 \x01(\x0b\x32&.prodvana.pipelines.ManualApprovalTaskH\x00\x12\x35\n\x0b\x63ustom_task\x18\x06 \x01(\x0b\x32\x1e.prodvana.pipelines.CustomTaskH\x00\x1a\x16\n\x08Metadata\x12\n\n\x02id\x18\x01 \x01(\x05\x42\x11\n\ntask_oneof\x12\x03\xf8\x42\x01\"\xda\x01\n\x0ePipelineConfig\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12\x38\n\x05tasks\x18\x02 \x03(\x0b\x32\x18.prodvana.pipelines.TaskB\x0f\xfa\x42\x0c\x92\x01\t\x08\x01\"\x05\x8a\x01\x02\x10\x01\x12\x10\n\x08rollback\x18\x03 \x01(\x08\x12\x41\n\rnotifications\x18\x04 \x01(\x0b\x32*.prodvana.common_config.NotificationConfig\"\xde\x01\n\x10PipelineTemplate\x12;\n\x0bname_suffix\x18\x01 \x01(\tB&\xfa\x42#r!\x10\x01\x18?2\x1b^([a-z0-9-]*[a-z0-9]){0,1}$\x12\x38\n\x05tasks\x18\x02 \x03(\x0b\x32\x18.prodvana.pipelines.TaskB\x0f\xfa\x42\x0c\x92\x01\t\x08\x01\"\x05\x8a\x01\x02\x10\x01\x12\x10\n\x08rollback\x18\x03 \x01(\x08\x12\x41\n\rnotifications\x18\x04 \x01(\x0b\x32*.prodvana.common_config.NotificationConfigBNZLgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pipelinesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.pipelines.pipelines_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pipelines'
  _WAITTASK.fields_by_name['duration']._options = None
  _WAITTASK.fields_by_name['duration']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _CUSTOMTASK.fields_by_name['description']._options = None
  _CUSTOMTASK.fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _CUSTOMTASK.fields_by_name['program']._options = None
  _CUSTOMTASK.fields_by_name['program']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TASK.oneofs_by_name['task_oneof']._options = None
  _TASK.oneofs_by_name['task_oneof']._serialized_options = b'\370B\001'
  _PIPELINECONFIG.fields_by_name['name']._options = None
  _PIPELINECONFIG.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _PIPELINECONFIG.fields_by_name['tasks']._options = None
  _PIPELINECONFIG.fields_by_name['tasks']._serialized_options = b'\372B\014\222\001\t\010\001\"\005\212\001\002\020\001'
  _PIPELINETEMPLATE.fields_by_name['name_suffix']._options = None
  _PIPELINETEMPLATE.fields_by_name['name_suffix']._serialized_options = b'\372B#r!\020\001\030?2\033^([a-z0-9-]*[a-z0-9]){0,1}$'
  _PIPELINETEMPLATE.fields_by_name['tasks']._options = None
  _PIPELINETEMPLATE.fields_by_name['tasks']._serialized_options = b'\372B\014\222\001\t\010\001\"\005\212\001\002\020\001'
  _globals['_PUSHTASK']._serialized_start=233
  _globals['_PUSHTASK']._serialized_end=396
  _globals['_WAITTASK']._serialized_start=398
  _globals['_WAITTASK']._serialized_end=465
  _globals['_PARALLELTASK']._serialized_start=468
  _globals['_PARALLELTASK']._serialized_end=596
  _globals['_PARALLELTASK_TASKTRACK']._serialized_start=544
  _globals['_PARALLELTASK_TASKTRACK']._serialized_end=596
  _globals['_MANUALAPPROVALTASK']._serialized_start=598
  _globals['_MANUALAPPROVALTASK']._serialized_end=618
  _globals['_CUSTOMTASK']._serialized_start=621
  _globals['_CUSTOMTASK']._serialized_end=918
  _globals['_TASK']._serialized_start=921
  _globals['_TASK']._serialized_end=1311
  _globals['_TASK_METADATA']._serialized_start=1270
  _globals['_TASK_METADATA']._serialized_end=1292
  _globals['_PIPELINECONFIG']._serialized_start=1314
  _globals['_PIPELINECONFIG']._serialized_end=1532
  _globals['_PIPELINETEMPLATE']._serialized_start=1535
  _globals['_PIPELINETEMPLATE']._serialized_end=1757
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.common_config.env_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PortConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Protocol:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ProtocolEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PortConfig._Protocol.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: PortConfig._Protocol.ValueType  # 0
        HTTP: PortConfig._Protocol.ValueType  # 1
        HTTP2: PortConfig._Protocol.ValueType  # 2
        GRPC: PortConfig._Protocol.ValueType  # 3
        TCP: PortConfig._Protocol.ValueType  # 4

    class Protocol(_Protocol, metaclass=_ProtocolEnumTypeWrapper): ...
    UNKNOWN: PortConfig.Protocol.ValueType  # 0
    HTTP: PortConfig.Protocol.ValueType  # 1
    HTTP2: PortConfig.Protocol.ValueType  # 2
    GRPC: PortConfig.Protocol.ValueType  # 3
    TCP: PortConfig.Protocol.ValueType  # 4

    PORT_FIELD_NUMBER: builtins.int
    TARGET_PORT_FIELD_NUMBER: builtins.int
    EXTERNAL_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    port: builtins.int
    target_port: builtins.int
    """optional, default to the same value as `port`"""
    external: builtins.bool
    """if this port should be exposed to the public internet"""
    protocol: global___PortConfig.Protocol.ValueType
    tls: builtins.bool
    """if the connection should use TLS"""
    def __init__(
        self,
        *,
        port: builtins.int = ...,
        target_port: builtins.int = ...,
        external: builtins.bool = ...,
        protocol: global___PortConfig.Protocol.ValueType = ...,
        tls: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["external", b"external", "port", b"port", "protocol", b"protocol", "target_port", b"target_port", "tls", b"tls"]) -> None: ...

global___PortConfig = PortConfig

class ResourceList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMORY_FIELD_NUMBER: builtins.int
    CPU_FIELD_NUMBER: builtins.int
    memory: builtins.str
    cpu: builtins.str
    def __init__(
        self,
        *,
        memory: builtins.str = ...,
        cpu: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu", b"cpu", "memory", b"memory"]) -> None: ...

global___ResourceList = ResourceList

class ResourceRequirements(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUESTS_FIELD_NUMBER: builtins.int
    LIMITS_FIELD_NUMBER: builtins.int
    @property
    def requests(self) -> global___ResourceList: ...
    @property
    def limits(self) -> global___ResourceList: ...
    def __init__(
        self,
        *,
        requests: global___ResourceList | None = ...,
        limits: global___ResourceList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["limits", b"limits", "requests", b"requests"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["limits", b"limits", "requests", b"requests"]) -> None: ...

global___ResourceRequirements = ResourceRequirements

class HttpProbe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    path: builtins.str
    port: builtins.int
    tls: builtins.bool
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        port: builtins.int = ...,
        tls: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "port", b"port", "tls", b"tls"]) -> None: ...

global___HttpProbe = HttpProbe

class CmdProbe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_FIELD_NUMBER: builtins.int
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        command: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command"]) -> None: ...

global___CmdProbe = CmdProbe

class TcpProbe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    port: builtins.int
    host: builtins.str
    def __init__(
        self,
        *,
        port: builtins.int = ...,
        host: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port"]) -> None: ...

global___TcpProbe = TcpProbe

class HealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_FIELD_NUMBER: builtins.int
    CMD_FIELD_NUMBER: builtins.int
    TCP_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    @property
    def http(self) -> global___HttpProbe: ...
    @property
    def cmd(self) -> global___CmdProbe: ...
    @property
    def tcp(self) -> global___TcpProbe: ...
    @property
    def delay(self) -> google.protobuf.duration_pb2.Duration: ...
    @property
    def period(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        http: global___HttpProbe | None = ...,
        cmd: global___CmdProbe | None = ...,
        tcp: global___TcpProbe | None = ...,
        delay: google.protobuf.duration_pb2.Duration | None = ...,
        period: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cmd", b"cmd", "delay", b"delay", "http", b"http", "period", b"period", "probe_config", b"probe_config", "tcp", b"tcp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cmd", b"cmd", "delay", b"delay", "http", b"http", "period", b"period", "probe_config", b"probe_config", "tcp", b"tcp"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["probe_config", b"probe_config"]) -> typing_extensions.Literal["http", "cmd", "tcp"] | None: ...

global___HealthCheck = HealthCheck

class ImageRegistryInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_REGISTRY_ID_FIELD_NUMBER: builtins.int
    CONTAINER_REGISTRY_FIELD_NUMBER: builtins.int
    IMAGE_REPOSITORY_FIELD_NUMBER: builtins.int
    container_registry_id: builtins.str
    """both container_registry_id and container_registry are supported, but only set one not both"""
    container_registry: builtins.str
    image_repository: builtins.str
    """Not the URL, everything after: username/reponame
    leaving it as once field because the spec considers it 1 field
    in theory you can have no username, or nest the repo names
    """
    def __init__(
        self,
        *,
        container_registry_id: builtins.str = ...,
        container_registry: builtins.str = ...,
        image_repository: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_registry", b"container_registry", "container_registry_id", b"container_registry_id", "image_repository", b"image_repository"]) -> None: ...

global___ImageRegistryInfo = ImageRegistryInfo

class ImageDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_INFO_FIELD_NUMBER: builtins.int
    IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def registry_info(self) -> global___ImageRegistryInfo: ...
    identifier: builtins.str
    """image tag or digest"""
    def __init__(
        self,
        *,
        registry_info: global___ImageRegistryInfo | None = ...,
        identifier: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["registry_info", b"registry_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "registry_info", b"registry_info"]) -> None: ...

global___ImageDetails = ImageDetails

class ProgramConfig(google.protobuf.message.Message):
    """This ProgramConfig is used in multiple places, including service configuration and custom pipeline tasks.
    The validations expressed here represent the lowest common denominator of the use cases.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IMAGE_TAG_FIELD_NUMBER: builtins.int
    IMAGE_REGISTRY_INFO_FIELD_NUMBER: builtins.int
    CMD_FIELD_NUMBER: builtins.int
    ENTRYPOINT_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    TEMPLATE_COMPLETE_FIELD_NUMBER: builtins.int
    WORKING_DIRECTORY_FIELD_NUMBER: builtins.int
    name: builtins.str
    image: builtins.str
    image_tag: builtins.str
    @property
    def image_registry_info(self) -> global___ImageRegistryInfo:
        """optional, not guaranteed to be compatible with `image` (e.g. if user decides to paste in a public image string)"""
    @property
    def cmd(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def entrypoint(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]: ...
    @property
    def resources(self) -> global___ResourceRequirements: ...
    @property
    def health_check(self) -> global___HealthCheck: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PortConfig]:
        """empty list is ok, default from docker image will be used"""
    template_complete: builtins.bool
    """Only set when this ServiceConfig represents a ServiceTemplate
    When set, this program will be added in whole to the target service's
    programs in full, and will not partially apply to a program with the
    same name in the target service's config.
    """
    working_directory: builtins.str
    """working directory, defaults to runtime's implementation (usually the default working directory in the docker image)"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        image: builtins.str = ...,
        image_tag: builtins.str = ...,
        image_registry_info: global___ImageRegistryInfo | None = ...,
        cmd: collections.abc.Iterable[builtins.str] | None = ...,
        entrypoint: collections.abc.Iterable[builtins.str] | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        resources: global___ResourceRequirements | None = ...,
        health_check: global___HealthCheck | None = ...,
        ports: collections.abc.Iterable[global___PortConfig] | None = ...,
        template_complete: builtins.bool = ...,
        working_directory: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check", b"health_check", "image_registry_info", b"image_registry_info", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cmd", b"cmd", "entrypoint", b"entrypoint", "env", b"env", "health_check", b"health_check", "image", b"image", "image_registry_info", b"image_registry_info", "image_tag", b"image_tag", "name", b"name", "ports", b"ports", "resources", b"resources", "template_complete", b"template_complete", "working_directory", b"working_directory"]) -> None: ...

global___ProgramConfig = ProgramConfig

class PerReleaseChannelProgramConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IMAGE_REGISTRY_INFO_FIELD_NUMBER: builtins.int
    IMAGE_TAG_FIELD_NUMBER: builtins.int
    name: builtins.str
    """must match a program in top-level program config"""
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]: ...
    image: builtins.str
    """If present, overrides main program config.
    TODO: If users need to enforce that different RCs require different images, add requires_separate_images option to ProgramConfig.
    This will prevent accidentally undoing separate images via the UI or autopush.
    """
    @property
    def image_registry_info(self) -> global___ImageRegistryInfo:
        """optional, not guaranteed to be compatible with `image` (e.g. if user decides to paste in a public image string)"""
    image_tag: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        image: builtins.str = ...,
        image_registry_info: global___ImageRegistryInfo | None = ...,
        image_tag: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["image_registry_info", b"image_registry_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "image", b"image", "image_registry_info", b"image_registry_info", "image_tag", b"image_tag", "name", b"name"]) -> None: ...

global___PerReleaseChannelProgramConfig = PerReleaseChannelProgramConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Maturity:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MaturityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Maturity.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FAST_ITERATION: _Maturity.ValueType  # 0
    PRELAUNCH: _Maturity.ValueType  # 1
    LIVE: _Maturity.ValueType  # 2

class Maturity(_Maturity, metaclass=_MaturityEnumTypeWrapper):
    """TODO(naphat) maturity likely should not be hardcoded but be flexible per organization"""

FAST_ITERATION: Maturity.ValueType  # 0
PRELAUNCH: Maturity.ValueType  # 1
LIVE: Maturity.ValueType  # 2
global___Maturity = Maturity



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/users/users.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aprodvana/users/users.proto\x12\x0eprodvana.users\"n\n\x04User\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08\x61pi_user\x18\x06 \x01(\x08\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\x12\x0e\n\x06\x65mails\x18\x05 \x03(\tBJZHgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/usersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.users.users_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZHgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/users'
  _globals['_USER']._serialized_start=46
  _globals['_USER']._serialized_end=156
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release_channel/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.release_channel import release_channel_config_pb2 as prodvana_dot_release__channel_dot_release__channel__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%prodvana/release_channel/object.proto\x12\x18prodvana.release_channel\x1a\x1aprodvana/object/meta.proto\x1a\x35prodvana/release_channel/release_channel_config.proto\"}\n\"ReleaseChannelProtectionAttachment\x12\x12\n\nprotection\x18\x01 \x01(\t\x12\x12\n\nattachment\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65sired_state_id\x18\x03 \x01(\t\x12\x15\n\rattachment_id\x18\x04 \x01(\t\"s\n\x13ReleaseChannelState\x12\\\n\x16protection_attachments\x18\x01 \x03(\x0b\x32<.prodvana.release_channel.ReleaseChannelProtectionAttachment\"\xb9\x01\n\x0eReleaseChannel\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12>\n\x06\x63onfig\x18\x02 \x01(\x0b\x32..prodvana.release_channel.ReleaseChannelConfig\x12<\n\x05state\x18\x03 \x01(\x0b\x32-.prodvana.release_channel.ReleaseChannelStateBTZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.release_channel.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channel'
  _globals['_RELEASECHANNELPROTECTIONATTACHMENT']._serialized_start=150
  _globals['_RELEASECHANNELPROTECTIONATTACHMENT']._serialized_end=275
  _globals['_RELEASECHANNELSTATE']._serialized_start=277
  _globals['_RELEASECHANNELSTATE']._serialized_end=392
  _globals['_RELEASECHANNEL']._serialized_start=395
  _globals['_RELEASECHANNEL']._serialized_end=580
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/deployment/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.deployment.model import object_pb2 as prodvana_dot_deployment_dot_model_dot_object__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/deployment/manager.proto\x12\x13prodvana.deployment\x1a\x1cgoogle/api/annotations.proto\x1a\x1aprodvana/object/meta.proto\x1a&prodvana/deployment/model/object.proto\x1a%prodvana/service/service_config.proto\x1a\x17validate/validate.proto\"m\n\x13RecordDeploymentReq\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32+.prodvana.deployment.model.DeploymentConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0f\n\x07pending\x18\x02 \x01(\x08\"A\n\x14RecordDeploymentResp\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\"o\n\x19UpdateDeploymentStatusReq\x12\x15\n\rdeployment_id\x18\x01 \x01(\t\x12;\n\x06status\x18\x02 \x01(\x0e\x32+.prodvana.deployment.model.DeploymentStatus\"Y\n\x1aUpdateDeploymentStatusResp\x12;\n\x06status\x18\x01 \x01(\x0e\x32+.prodvana.deployment.model.DeploymentStatus\"\x81\x01\n\x10\x44\x65ploymentFilter\x12\x10\n\x08services\x18\x01 \x03(\t\x12\x18\n\x10release_channels\x18\x02 \x03(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\x12\x18\n\x10\x64\x65sired_state_id\x18\x04 \x01(\t\x12\x12\n\nrelease_id\x18\x05 \x01(\t\"\xe8\x01\n\x12ListDeploymentsReq\x12\x36\n\x07\x66ilters\x18\x01 \x03(\x0b\x32%.prodvana.deployment.DeploymentFilter\x12\x35\n\x06\x66ilter\x18\x02 \x01(\x0b\x32%.prodvana.deployment.DeploymentFilter\x12\x1e\n\x16starting_deployment_id\x18\x03 \x01(\t\x12\x1c\n\x14\x65nding_deployment_id\x18\x04 \x01(\t\x12\x12\n\npage_token\x18\x05 \x01(\t\x12\x11\n\tpage_size\x18\x06 \x01(\x05\"j\n\x13ListDeploymentsResp\x12:\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32%.prodvana.deployment.model.Deployment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xbd\x02\n\rDeploymentRef\x12\x17\n\rdeployment_id\x18\x01 \x01(\tH\x00\x12=\n\x06\x63onfig\x18\x02 \x01(\x0b\x32+.prodvana.deployment.model.DeploymentConfigH\x00\x12[\n\x17service_instance_config\x18\x03 \x01(\x0b\x32\x38.prodvana.deployment.DeploymentRef.ServiceInstanceConfigH\x00\x1ak\n\x15ServiceInstanceConfig\x12R\n\x0f\x63ompiled_config\x18\x01 \x01(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\n\n\x03ref\x12\x03\xf8\x42\x01\"\x99\x01\n\x14\x43ompareDeploymentReq\x12\x44\n\x0enew_deployment\x18\x01 \x01(\x0b\x32\".prodvana.deployment.DeploymentRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12;\n\x0fprev_deployment\x18\x02 \x01(\x0b\x32\".prodvana.deployment.DeploymentRef\"\\\n\x15\x43ompareDeploymentResp\x12\x43\n\ncomparison\x18\x01 \x01(\x0b\x32/.prodvana.deployment.model.DeploymentComparison\"\x9a\x01\n\x14PreviewDeploymentReq\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32+.prodvana.deployment.model.DeploymentConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12;\n\x0fprev_deployment\x18\x02 \x01(\x0b\x32\".prodvana.deployment.DeploymentRef\"R\n\x15PreviewDeploymentResp\x12\x39\n\ndeployment\x18\x01 \x01(\x0b\x32%.prodvana.deployment.model.Deployment\"\xec\x01\n\x17GetLatestDeploymentsReq\x12\x36\n\x07\x66ilters\x18\x01 \x03(\x0b\x32%.prodvana.deployment.DeploymentFilter\x12\x35\n\x06\x66ilter\x18\x02 \x01(\x0b\x32%.prodvana.deployment.DeploymentFilter\x12;\n\x06status\x18\x03 \x01(\x0e\x32+.prodvana.deployment.model.DeploymentStatus\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\"o\n\x18GetLatestDeploymentsResp\x12:\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32%.prodvana.deployment.model.Deployment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"u\n\x19\x44\x65ploymentServiceInstance\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xee\x01\n\x1a\x43heckCommitInDeploymentReq\x12 \n\rdeployment_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12_\n\x1b\x64\x65ployment_service_instance\x18\x02 \x01(\x0b\x32..prodvana.deployment.DeploymentServiceInstanceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x1b\n\nrepository\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x06\x63ommit\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x17\n\x10\x64\x65ployment_oneof\x12\x03\xf8\x42\x01\"\xae\x01\n\x1b\x43heckCommitInDeploymentResp\x12G\n\x06result\x18\x01 \x01(\x0e\x32\x37.prodvana.deployment.CheckCommitInDeploymentResp.Result\"F\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08INCLUDED\x10\x01\x12\x0f\n\x0bNO_RELATION\x10\x02\x12\x10\n\x0cNOT_INCLUDED\x10\x03\x32\x96\t\n\x11\x44\x65ploymentManager\x12\x83\x01\n\x10RecordDeployment\x12(.prodvana.deployment.RecordDeploymentReq\x1a).prodvana.deployment.RecordDeploymentResp\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/deployments:\x01*\x12\xae\x01\n\x16UpdateDeploymentStatus\x12..prodvana.deployment.UpdateDeploymentStatusReq\x1a/.prodvana.deployment.UpdateDeploymentStatusResp\"3\x82\xd3\xe4\x93\x02-\"(/v1/deployments/{deployment_id=*}/status:\x01*\x12}\n\x0fListDeployments\x12\'.prodvana.deployment.ListDeploymentsReq\x1a(.prodvana.deployment.ListDeploymentsResp\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/deployments\x12n\n\x15ListDeploymentsStream\x12\'.prodvana.deployment.ListDeploymentsReq\x1a(.prodvana.deployment.ListDeploymentsResp\"\x00\x30\x01\x12\x8e\x01\n\x11\x43ompareDeployment\x12).prodvana.deployment.CompareDeploymentReq\x1a*.prodvana.deployment.CompareDeploymentResp\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/deployments/compare:\x01*\x12\x8e\x01\n\x11PreviewDeployment\x12).prodvana.deployment.PreviewDeploymentReq\x1a*.prodvana.deployment.PreviewDeploymentResp\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/deployments/preview:\x01*\x12\x93\x01\n\x14GetLatestDeployments\x12,.prodvana.deployment.GetLatestDeploymentsReq\x1a-.prodvana.deployment.GetLatestDeploymentsResp\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/deployments/latest\x12\xa2\x01\n\x17\x43heckCommitInDeployment\x12/.prodvana.deployment.CheckCommitInDeploymentReq\x1a\x30.prodvana.deployment.CheckCommitInDeploymentResp\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/deployments/check_commitBOZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/deploymentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.deployment.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/deployment'
  _RECORDDEPLOYMENTREQ.fields_by_name['config']._options = None
  _RECORDDEPLOYMENTREQ.fields_by_name['config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DEPLOYMENTREF_SERVICEINSTANCECONFIG.fields_by_name['compiled_config']._options = None
  _DEPLOYMENTREF_SERVICEINSTANCECONFIG.fields_by_name['compiled_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DEPLOYMENTREF.oneofs_by_name['ref']._options = None
  _DEPLOYMENTREF.oneofs_by_name['ref']._serialized_options = b'\370B\001'
  _COMPAREDEPLOYMENTREQ.fields_by_name['new_deployment']._options = None
  _COMPAREDEPLOYMENTREQ.fields_by_name['new_deployment']._serialized_options = b'\372B\005\212\001\002\020\001'
  _PREVIEWDEPLOYMENTREQ.fields_by_name['config']._options = None
  _PREVIEWDEPLOYMENTREQ.fields_by_name['config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DEPLOYMENTSERVICEINSTANCE.fields_by_name['application']._options = None
  _DEPLOYMENTSERVICEINSTANCE.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _DEPLOYMENTSERVICEINSTANCE.fields_by_name['service']._options = None
  _DEPLOYMENTSERVICEINSTANCE.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _DEPLOYMENTSERVICEINSTANCE.fields_by_name['release_channel']._options = None
  _DEPLOYMENTSERVICEINSTANCE.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _CHECKCOMMITINDEPLOYMENTREQ.oneofs_by_name['deployment_oneof']._options = None
  _CHECKCOMMITINDEPLOYMENTREQ.oneofs_by_name['deployment_oneof']._serialized_options = b'\370B\001'
  _CHECKCOMMITINDEPLOYMENTREQ.fields_by_name['deployment_id']._options = None
  _CHECKCOMMITINDEPLOYMENTREQ.fields_by_name['deployment_id']._serialized_options = b'\372B\004r\002\020\001'
  _CHECKCOMMITINDEPLOYMENTREQ.fields_by_name['deployment_service_instance']._options = None
  _CHECKCOMMITINDEPLOYMENTREQ.fields_by_name['deployment_service_instance']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CHECKCOMMITINDEPLOYMENTREQ.fields_by_name['repository']._options = None
  _CHECKCOMMITINDEPLOYMENTREQ.fields_by_name['repository']._serialized_options = b'\372B\004r\002\020\001'
  _CHECKCOMMITINDEPLOYMENTREQ.fields_by_name['commit']._options = None
  _CHECKCOMMITINDEPLOYMENTREQ.fields_by_name['commit']._serialized_options = b'\372B\004r\002\020\001'
  _DEPLOYMENTMANAGER.methods_by_name['RecordDeployment']._options = None
  _DEPLOYMENTMANAGER.methods_by_name['RecordDeployment']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/deployments:\001*'
  _DEPLOYMENTMANAGER.methods_by_name['UpdateDeploymentStatus']._options = None
  _DEPLOYMENTMANAGER.methods_by_name['UpdateDeploymentStatus']._serialized_options = b'\202\323\344\223\002-\"(/v1/deployments/{deployment_id=*}/status:\001*'
  _DEPLOYMENTMANAGER.methods_by_name['ListDeployments']._options = None
  _DEPLOYMENTMANAGER.methods_by_name['ListDeployments']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/deployments'
  _DEPLOYMENTMANAGER.methods_by_name['CompareDeployment']._options = None
  _DEPLOYMENTMANAGER.methods_by_name['CompareDeployment']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/deployments/compare:\001*'
  _DEPLOYMENTMANAGER.methods_by_name['PreviewDeployment']._options = None
  _DEPLOYMENTMANAGER.methods_by_name['PreviewDeployment']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/deployments/preview:\001*'
  _DEPLOYMENTMANAGER.methods_by_name['GetLatestDeployments']._options = None
  _DEPLOYMENTMANAGER.methods_by_name['GetLatestDeployments']._serialized_options = b'\202\323\344\223\002\030\022\026/v1/deployments/latest'
  _DEPLOYMENTMANAGER.methods_by_name['CheckCommitInDeployment']._options = None
  _DEPLOYMENTMANAGER.methods_by_name['CheckCommitInDeployment']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/deployments/check_commit'
  _globals['_RECORDDEPLOYMENTREQ']._serialized_start=220
  _globals['_RECORDDEPLOYMENTREQ']._serialized_end=329
  _globals['_RECORDDEPLOYMENTRESP']._serialized_start=331
  _globals['_RECORDDEPLOYMENTRESP']._serialized_end=396
  _globals['_UPDATEDEPLOYMENTSTATUSREQ']._serialized_start=398
  _globals['_UPDATEDEPLOYMENTSTATUSREQ']._serialized_end=509
  _globals['_UPDATEDEPLOYMENTSTATUSRESP']._serialized_start=511
  _globals['_UPDATEDEPLOYMENTSTATUSRESP']._serialized_end=600
  _globals['_DEPLOYMENTFILTER']._serialized_start=603
  _globals['_DEPLOYMENTFILTER']._serialized_end=732
  _globals['_LISTDEPLOYMENTSREQ']._serialized_start=735
  _globals['_LISTDEPLOYMENTSREQ']._serialized_end=967
  _globals['_LISTDEPLOYMENTSRESP']._serialized_start=969
  _globals['_LISTDEPLOYMENTSRESP']._serialized_end=1075
  _globals['_DEPLOYMENTREF']._serialized_start=1078
  _globals['_DEPLOYMENTREF']._serialized_end=1395
  _globals['_DEPLOYMENTREF_SERVICEINSTANCECONFIG']._serialized_start=1276
  _globals['_DEPLOYMENTREF_SERVICEINSTANCECONFIG']._serialized_end=1383
  _globals['_COMPAREDEPLOYMENTREQ']._serialized_start=1398
  _globals['_COMPAREDEPLOYMENTREQ']._serialized_end=1551
  _globals['_COMPAREDEPLOYMENTRESP']._serialized_start=1553
  _globals['_COMPAREDEPLOYMENTRESP']._serialized_end=1645
  _globals['_PREVIEWDEPLOYMENTREQ']._serialized_start=1648
  _globals['_PREVIEWDEPLOYMENTREQ']._serialized_end=1802
  _globals['_PREVIEWDEPLOYMENTRESP']._serialized_start=1804
  _globals['_PREVIEWDEPLOYMENTRESP']._serialized_end=1886
  _globals['_GETLATESTDEPLOYMENTSREQ']._serialized_start=1889
  _globals['_GETLATESTDEPLOYMENTSREQ']._serialized_end=2125
  _globals['_GETLATESTDEPLOYMENTSRESP']._serialized_start=2127
  _globals['_GETLATESTDEPLOYMENTSRESP']._serialized_end=2238
  _globals['_DEPLOYMENTSERVICEINSTANCE']._serialized_start=2240
  _globals['_DEPLOYMENTSERVICEINSTANCE']._serialized_end=2357
  _globals['_CHECKCOMMITINDEPLOYMENTREQ']._serialized_start=2360
  _globals['_CHECKCOMMITINDEPLOYMENTREQ']._serialized_end=2598
  _globals['_CHECKCOMMITINDEPLOYMENTRESP']._serialized_start=2601
  _globals['_CHECKCOMMITINDEPLOYMENTRESP']._serialized_end=2775
  _globals['_CHECKCOMMITINDEPLOYMENTRESP_RESULT']._serialized_start=2705
  _globals['_CHECKCOMMITINDEPLOYMENTRESP_RESULT']._serialized_end=2775
  _globals['_DEPLOYMENTMANAGER']._serialized_start=2778
  _globals['_DEPLOYMENTMANAGER']._serialized_end=3952
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.protection.protection_reference_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AttachmentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AttachmentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AttachmentType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _AttachmentType.ValueType  # 0
    RELEASE_CHANNEL: _AttachmentType.ValueType  # 1
    SERVICE_INSTANCE: _AttachmentType.ValueType  # 2
    CONVERGENCE: _AttachmentType.ValueType  # 3

class AttachmentType(_AttachmentType, metaclass=_AttachmentTypeEnumTypeWrapper): ...

UNKNOWN: AttachmentType.ValueType  # 0
RELEASE_CHANNEL: AttachmentType.ValueType  # 1
SERVICE_INSTANCE: AttachmentType.ValueType  # 2
CONVERGENCE: AttachmentType.ValueType  # 3
global___AttachmentType = AttachmentType

class ProtectionAttachmentConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    REF_FIELD_NUMBER: builtins.int
    LIFECYCLE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """optional, default to protection name"""
    @property
    def ref(self) -> prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionReference: ...
    @property
    def lifecycle(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionLifecycle]:
        """if set, the attachment is automatically used in all deployments for the subject of this attachment.
        e.g. for release channels, all service instances in that release channel will use the attachment.
        """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        ref: prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionReference | None = ...,
        lifecycle: collections.abc.Iterable[prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionLifecycle] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ref", b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lifecycle", b"lifecycle", "name", b"name", "ref", b"ref"]) -> None: ...

global___ProtectionAttachmentConfig = ProtectionAttachmentConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/async_task/task_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'prodvana/async_task/task_metadata.proto\x12\x13prodvana.async_task\"\x19\n\nTaskResult\x12\x0b\n\x03log\x18\x01 \x01(\x0c*L\n\nTaskStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42OZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/async_taskb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.async_task.task_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/async_task'
  _globals['_TASKSTATUS']._serialized_start=91
  _globals['_TASKSTATUS']._serialized_end=167
  _globals['_TASKRESULT']._serialized_start=64
  _globals['_TASKRESULT']._serialized_end=89
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.organization import organization_manager_pb2 as prodvana_dot_organization_dot_organization__manager__pb2


class OrganizationManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetOrganization = channel.unary_unary(
                '/prodvana.organization.OrganizationManager/GetOrganization',
                request_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationReq.SerializeToString,
                response_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationResp.FromString,
                )
        self.GetOrganizationMetrics = channel.unary_unary(
                '/prodvana.organization.OrganizationManager/GetOrganizationMetrics',
                request_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetricsReq.SerializeToString,
                response_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetricsResp.FromString,
                )
        self.GetOrganizationInsights = channel.unary_unary(
                '/prodvana.organization.OrganizationManager/GetOrganizationInsights',
                request_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationInsightsReq.SerializeToString,
                response_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationInsightsResp.FromString,
                )
        self.SnoozeOrganizationInsight = channel.unary_unary(
                '/prodvana.organization.OrganizationManager/SnoozeOrganizationInsight',
                request_serializer=prodvana_dot_organization_dot_organization__manager__pb2.SnoozeOrganizationInsightReq.SerializeToString,
                response_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.SnoozeOrganizationInsightResp.FromString,
                )
        self.GetOrganizationMetadata = channel.unary_unary(
                '/prodvana.organization.OrganizationManager/GetOrganizationMetadata',
                request_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetadataReq.SerializeToString,
                response_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetadataResp.FromString,
                )
        self.SetOrganizationMetadata = channel.unary_unary(
                '/prodvana.organization.OrganizationManager/SetOrganizationMetadata',
                request_serializer=prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationMetadataReq.SerializeToString,
                response_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationMetadataResp.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/prodvana.organization.OrganizationManager/GetUser',
                request_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetUserReq.SerializeToString,
                response_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetUserResp.FromString,
                )
        self.GetOrganizationSubscriptionStatus = channel.unary_unary(
                '/prodvana.organization.OrganizationManager/GetOrganizationSubscriptionStatus',
                request_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSubscriptionStatusReq.SerializeToString,
                response_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSubscriptionStatusResp.FromString,
                )
        self.GetOrganizationSettings = channel.unary_unary(
                '/prodvana.organization.OrganizationManager/GetOrganizationSettings',
                request_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSettingsReq.SerializeToString,
                response_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSettingsResp.FromString,
                )
        self.SetOrganizationSettings = channel.unary_unary(
                '/prodvana.organization.OrganizationManager/SetOrganizationSettings',
                request_serializer=prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationSettingsReq.SerializeToString,
                response_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationSettingsResp.FromString,
                )


class OrganizationManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationMetrics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationInsights(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SnoozeOrganizationInsight(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationMetadata(self, request, context):
        """Get org metadata, useful for constructing edit workflows for metadata
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetOrganizationMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Get a user in an organization, will return NOT_FOUND if the user is eitehr missing or not in an organization
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationSubscriptionStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetOrganizationSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OrganizationManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganization,
                    request_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationReq.FromString,
                    response_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationResp.SerializeToString,
            ),
            'GetOrganizationMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationMetrics,
                    request_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetricsReq.FromString,
                    response_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetricsResp.SerializeToString,
            ),
            'GetOrganizationInsights': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationInsights,
                    request_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationInsightsReq.FromString,
                    response_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationInsightsResp.SerializeToString,
            ),
            'SnoozeOrganizationInsight': grpc.unary_unary_rpc_method_handler(
                    servicer.SnoozeOrganizationInsight,
                    request_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.SnoozeOrganizationInsightReq.FromString,
                    response_serializer=prodvana_dot_organization_dot_organization__manager__pb2.SnoozeOrganizationInsightResp.SerializeToString,
            ),
            'GetOrganizationMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationMetadata,
                    request_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetadataReq.FromString,
                    response_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetadataResp.SerializeToString,
            ),
            'SetOrganizationMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.SetOrganizationMetadata,
                    request_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationMetadataReq.FromString,
                    response_serializer=prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationMetadataResp.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetUserReq.FromString,
                    response_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetUserResp.SerializeToString,
            ),
            'GetOrganizationSubscriptionStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationSubscriptionStatus,
                    request_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSubscriptionStatusReq.FromString,
                    response_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSubscriptionStatusResp.SerializeToString,
            ),
            'GetOrganizationSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationSettings,
                    request_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSettingsReq.FromString,
                    response_serializer=prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSettingsResp.SerializeToString,
            ),
            'SetOrganizationSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetOrganizationSettings,
                    request_deserializer=prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationSettingsReq.FromString,
                    response_serializer=prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationSettingsResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.organization.OrganizationManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OrganizationManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.organization.OrganizationManager/GetOrganization',
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationReq.SerializeToString,
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.organization.OrganizationManager/GetOrganizationMetrics',
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetricsReq.SerializeToString,
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetricsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationInsights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.organization.OrganizationManager/GetOrganizationInsights',
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationInsightsReq.SerializeToString,
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationInsightsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SnoozeOrganizationInsight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.organization.OrganizationManager/SnoozeOrganizationInsight',
            prodvana_dot_organization_dot_organization__manager__pb2.SnoozeOrganizationInsightReq.SerializeToString,
            prodvana_dot_organization_dot_organization__manager__pb2.SnoozeOrganizationInsightResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.organization.OrganizationManager/GetOrganizationMetadata',
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetadataReq.SerializeToString,
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationMetadataResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetOrganizationMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.organization.OrganizationManager/SetOrganizationMetadata',
            prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationMetadataReq.SerializeToString,
            prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationMetadataResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.organization.OrganizationManager/GetUser',
            prodvana_dot_organization_dot_organization__manager__pb2.GetUserReq.SerializeToString,
            prodvana_dot_organization_dot_organization__manager__pb2.GetUserResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationSubscriptionStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.organization.OrganizationManager/GetOrganizationSubscriptionStatus',
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSubscriptionStatusReq.SerializeToString,
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSubscriptionStatusResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.organization.OrganizationManager/GetOrganizationSettings',
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSettingsReq.SerializeToString,
            prodvana_dot_organization_dot_organization__manager__pb2.GetOrganizationSettingsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetOrganizationSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.organization.OrganizationManager/SetOrganizationSettings',
            prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationSettingsReq.SerializeToString,
            prodvana_dot_organization_dot_organization__manager__pb2.SetOrganizationSettingsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
